@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2024 Univention GmbH
+# Copyright 2013-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -112,7 +112,7 @@ class UCSTestConfigRegistry(ConfigRegistry):
         # load new/original values
         self.load()
 
-    def __enter__(self) -> UCSTestConfigRegistry:  # FIXME Py3.9: Self
+    def __enter__(self) -> UCSTestConfigRegistry:  # FIXME: Py3.9: Self
         self.load()
         return self
 
