@@ -2,7 +2,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2013-2024 Univention GmbH
+# Copyright 2013-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -1118,7 +1118,7 @@ class UCSTestUDM:
             except psutil.NoSuchProcess:
                 pass
         for signal in (15, 9):
-            for proc in procs:
+            for proc in procs[:]:
                 try:
                     print(f'sending signal {signal} to process {proc.pid} ({proc.cmdline()!r})')
                     os.kill(proc.pid, signal)
